@@ -2,6 +2,8 @@
 class Pipeline(object):
     def read(self, file):
         pass
+    def get_stages(self):
+        return self.stages
 
 riscv_priv_modes = {3: "M", 2: "H", 1: "S", 0: "U"}
 
